@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -22,7 +21,7 @@ namespace gdcm
 
 /**
  * \brief Class to do system operation
- * \details OS independant functionalities
+ * \details OS independent functionalities
  */
 class GDCM_EXPORT System
 {
@@ -41,7 +40,7 @@ public:
   static const char *GetLastSystemError();
 
   /// Return the filesize. 0 if file does not exist.
-  /// \warning you need to use FileExists to differenciate between empty file and missing file.
+  /// \warning you need to use FileExists to differentiate between empty file and missing file.
   /// \warning for very large size file and on system where size_t is not appropriate to store
   /// off_t value the function will return 0.
   static size_t FileSize(const char* filename);
@@ -66,23 +65,25 @@ public:
   // Chdir
   // copy a file
 
-  /// \deprecated DO NOT USE: This function might disapear real time soon...
-  static bool GetHardwareAddress(unsigned char addr[6]);
+  /// \deprecated DO NOT USE: This function might disappear real time soon...
+  GDCM_LEGACY(static bool GetHardwareAddress(unsigned char addr[6]))
 
   /// Retrieve the hostname, only the first 255 byte are copyied.
   /// This may come handy to specify the Station Name
   static bool GetHostName(char hostname[255]);
 
-  // somewhat UID specific:
-  // In the following the size '22' is explicitely listed. You need to pass in at least 22bytes of
-  // array. If the string is an output it will be automatically padded ( array[21] == 0 ) for you.
-  // Those functions: GetCurrentDateTime / FormatDateTime / ParseDateTime do not return the
-  // &YYZZ part of the DT structure as defined in DICOM PS 3.5 - 2008
-  // In this case it is simple to split the date[22] into a DA and TM structure !
+  // In the following the size '22' is explicitly listed. You need to pass in
+  // at least 22bytes of array. If the string is an output it will be
+  // automatically padded ( array[21] == 0 ) for you.
+  // Those functions: GetCurrentDateTime / FormatDateTime / ParseDateTime do
+  // not return the &YYZZ part of the DT structure as defined in DICOM PS 3.5 -
+  // 2008 In this case it is simple to split the date[22] into a DA and TM
+  // structure
 
   /// Return the current data time, and format it as ASCII text.
-  // That's simply a call to gettimeofday + FormatDateTime, but since WIN32 do not have an
-  // implementation for gettimeofday this is more portable. (and time(0) is not precise)
+  /// This is simply a call to gettimeofday + FormatDateTime, since WIN32 do not have an
+  /// implementation for gettimeofday, this is more portable.
+  /// The call time(0) is not precise for our resolution
   static bool GetCurrentDateTime(char date[22]);
 
   /// format as ASCII text a time_t with milliseconds
@@ -97,10 +98,15 @@ public:
   /// \see FormatDateTime
   static bool ParseDateTime(time_t &timep, long &milliseconds, const char date[22]);
 
-  /// Encode bytes
+  /// Return the value for Timezone Offset From UTC as string.
+  /// \warning not thread safe
+  static const char *GetTimezoneOffsetFromUTC();
+
+  /// Used internally by the UIDGenerator class to convert a uuid tape to a
+  /// DICOM VR:UI type
   static size_t EncodeBytes(char *out, const unsigned char *data, int size);
 
-  /// consistant func for C99 spec of strcasecmp/strncasecmp
+  /// consistent func for C99 spec of strcasecmp/strncasecmp
   static int StrCaseCmp(const char *s1, const char *s2);
   /// \pre n != 0
   static int StrNCaseCmp(const char *s1, const char *s2, size_t n);
@@ -114,6 +120,9 @@ public:
   /// strtok_r
   static char *StrTokR(char *ptr, const char *sep, char **end);
 
+  /// return `locale charmap`
+  static const char *GetLocaleCharset();
+
   /// NOT THREAD SAFE
 /*
   static void SetArgv0(const char *);
