@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -88,12 +87,17 @@ public:
   /// Set/Get File
   void SetFile(File& file) { F = &file; }
 
-  /// Will read only up to Tag 'tag'
-  bool ReadUpToTag(const Tag & tag, std::set<Tag> const & skiptags);
+  /// Will read only up to Tag \param tag and skipping any tag specified in
+  /// \param skiptags
+  bool ReadUpToTag(const Tag & tag, std::set<Tag> const & skiptags = std::set<Tag>() );
 
   /// Will only read the specified selected tags.
   bool ReadSelectedTags(std::set<Tag> const & tags);
 
+  /// Test whether this is a DICOM file
+  /// \warning need to call either SetFileName or SetStream first
+  bool CanRead() const;
+
 protected:
   bool ReadPreamble();
   bool ReadMetaInformation();
