@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -118,6 +117,7 @@ std::istream& Read(std::istream &is)
       }
     catch(Exception &ex)
       {
+      (void)ex;  //to avoid unreferenced variable warning on release
 #ifdef GDCM_SUPPORT_BROKEN_IMPLEMENTATION
       // that's ok ! In all cases the whole file was read, because Fragment::Read only fail on eof() reached
       // 1. SIEMENS-JPEG-CorruptFrag.dcm is more difficult to deal with, we have a partial fragment, read
