@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -33,7 +32,7 @@
 namespace gdcm
 {
 
-Writer::Writer():Stream(NULL),Ofstream(NULL),F(new File),CheckFileMetaInformation(true)
+Writer::Writer():Stream(NULL),Ofstream(NULL),F(new File),CheckFileMetaInformation(true),WriteDataSetOnly(false)
 {
 }
 
@@ -41,7 +40,6 @@ Writer::~Writer()
 {
   if (Ofstream)
     {
-    Ofstream->close();
     delete Ofstream;
     Ofstream = NULL;
     Stream = NULL;
@@ -50,27 +48,25 @@ Writer::~Writer()
 
 bool Writer::Write()
 {
-  if( !Stream )
+  if( !Stream || !*Stream )
     {
     gdcmErrorMacro( "No Filename" );
     return false;
     }
 
-  //assert( F );
-  //F->Write( Stream );
-std::ostream &os = *Stream;
-FileMetaInformation &Header = F->GetHeader();
-DataSet &DS = F->GetDataSet();
+  std::ostream &os = *Stream;
+  FileMetaInformation &Header = F->GetHeader();
+  DataSet &DS = F->GetDataSet();
 
-if( DS.IsEmpty() )
-  {
-  gdcmErrorMacro( "DS empty" );
-  return false;
-  }
+  if( DS.IsEmpty() )
+    {
+    gdcmErrorMacro( "DS empty" );
+    return false;
+    }
 
   // Should I check that 0002,0002 / 0008,0016 and 0002,0003 / 0008,0018 match ?
 
-  try
+  if( !WriteDataSetOnly )
     {
     if( CheckFileMetaInformation )
       {
@@ -81,6 +77,7 @@ if( DS.IsEmpty() )
         }
       catch(gdcm::Exception &ex)
         {
+		(void)ex;  //to avoid unreferenced variable warning on release
         gdcmErrorMacro( "Could not recreate the File Meta Header, please report:" << ex.what() );
         return false;
         }
@@ -91,25 +88,6 @@ if( DS.IsEmpty() )
       Header.Write(os);
       }
     }
-  catch( std::exception &ex)
-    {
-    assert(0);
-    // File such as PICKER-16-MONO2-No_DicomV3_Preamble.dcm
-    // are a pain to rewrite since the metaheader was declared as implicit
-    // we have to do a look up the in the dictionary to find out VR for those element
-    // this is too much work, and should be up to the user to convert the meta to something
-    // legal ! Write them as implicit for now
-    gdcmWarningMacro( "File written will not be legal: " << ex.what() );
-    if( Header.GetPreamble().IsEmpty() )
-      {
-      os.seekp(0, std::ios::beg);
-      }
-    else
-      {
-      os.seekp(128+4, std::ios::beg);
-      }
-      Header.DataSet::Write<ImplicitDataElement,SwapperNoOp>(os);
-    }
 
   const TransferSyntax &ts = Header.GetDataSetTransferSyntax();
   if( !ts.IsValid() )
@@ -121,61 +99,65 @@ if( DS.IsEmpty() )
   if( ts == TransferSyntax::DeflatedExplicitVRLittleEndian )
     {
     //gzostream gzos(os.rdbuf());
-{
-    zlib_stream::zip_ostream gzos( os );
-    assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
-    DS.Write<ExplicitDataElement,SwapperNoOp>(gzos);
-    //gzos.flush();
-}
-
-    return os;
-    }
-
-try
-{
-  if( ts.GetSwapCode() == SwapCode::BigEndian )
-    {
-    //US-RGB-8-epicard.dcm is big endian
-    if( ts.GetNegociatedType() == TransferSyntax::Implicit )
-      {
-      // There is no such thing as Implicit Big Endian... oh well
-      // LIBIDO-16-ACR_NEMA-Volume.dcm
-      DS.Write<ImplicitDataElement,SwapperDoOp>(os);
-      }
-    else
-      {
+      try {
+      zlib_stream::zip_ostream gzos( os );
       assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
-      DS.Write<ExplicitDataElement,SwapperDoOp>(os);
-      }
-    }
-  else // LittleEndian
-    {
-    if( ts.GetNegociatedType() == TransferSyntax::Implicit )
-      {
-      DS.Write<ImplicitDataElement,SwapperNoOp>(os);
-      }
-    else
-      {
-      assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
-      DS.Write<ExplicitDataElement,SwapperNoOp>(os);
-      }
-    }
-}
-catch(std::exception &ex)
-{
-  gdcmErrorMacro( ex.what() );
-  return false;
-}
-catch(...)
-{
-  gdcmErrorMacro( "what the hell" );
-  return false;
-}
+      DS.Write<ExplicitDataElement,SwapperNoOp>(gzos);
+      //gzos.flush();
+      } catch (...){
+		  return false;
+	  }
 
-if (Ofstream)
-{
-  Ofstream->flush();
-}
+    return true;//os;
+    }
+
+  try
+    {
+    if( ts.GetSwapCode() == SwapCode::BigEndian )
+      {
+      //US-RGB-8-epicard.dcm is big endian
+      if( ts.GetNegociatedType() == TransferSyntax::Implicit )
+        {
+        // There is no such thing as Implicit Big Endian... oh well
+        // LIBIDO-16-ACR_NEMA-Volume.dcm
+        DS.Write<ImplicitDataElement,SwapperDoOp>(os);
+        }
+      else
+        {
+        assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
+        DS.Write<ExplicitDataElement,SwapperDoOp>(os);
+        }
+      }
+    else // LittleEndian
+      {
+      if( ts.GetNegociatedType() == TransferSyntax::Implicit )
+        {
+        DS.Write<ImplicitDataElement,SwapperNoOp>(os);
+        }
+      else
+        {
+        assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
+        DS.Write<ExplicitDataElement,SwapperNoOp>(os);
+        }
+      }
+    }
+  catch(std::exception &ex)
+    {
+	(void)ex;  //to avoid unreferenced variable warning on release
+    gdcmErrorMacro( ex.what() );
+    return false;
+    }
+  catch(...)
+    {
+    gdcmErrorMacro( "what the hell" );
+    return false;
+    }
+
+  os.flush();
+  if (Ofstream)
+    {
+    Ofstream->close();
+    }
 
   return true;
 }
