@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -99,7 +98,6 @@ bool Anonymizer::Empty( Tag const &t)
 
 bool Anonymizer::Remove( Tag const &t )
 {
-  if( t.GetGroup() < 0x0008 ) return false;
   DataSet &ds = F->GetDataSet();
   return ds.Remove( t ) == 1;
 }
@@ -830,7 +828,7 @@ bool Anonymizer::BALCPProtect(DataSet &ds, Tag const & tag, IOD const & iod)
 
       if( !copy.IsEmpty() )
         {
-        if( ByteValue *bv = copy.GetByteValue() )
+        if( const ByteValue *bv = copy.GetByteValue() )
           {
           UIDToAnonymize = std::string( bv->GetPointer(), bv->GetLength() );
           }
