@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -295,6 +294,9 @@ void Curve::SetCurve(const char *array, unsigned int length)
 
 void Curve::Decode(std::istream &is, std::ostream &os)
 {
+  (void)is;
+  (void)os;
+  assert(0);
 }
 
 void Curve::GetAsPoints(float *array) const
@@ -303,7 +305,7 @@ void Curve::GetAsPoints(float *array) const
   assert( Internal->Data.size() == (uint32_t)Internal->NumberOfPoints * 2 );
   assert( Internal->Dimensions == 1 || Internal->Dimensions == 2 );
   assert( Internal->DataValueRepresentation == 0 ); // 0 => unsigned short
-  // GE_DLX-8-MONO2-Multiframe.dcm has 969 points ! what in the *** is the last 
+  // GE_DLX-8-MONO2-Multiframe.dcm has 969 points ! what in the *** is the last
   // point doing here ?
   for(unsigned short i = 0; i < (Internal->NumberOfPoints / 2) * 2; i+=2 )
     {
@@ -315,4 +317,3 @@ void Curve::GetAsPoints(float *array) const
 }
 
 }
-
