@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -31,6 +30,7 @@ bool ImageApplyLookupTable::Apply()
   const gdcm::LookupTable &lut = image.GetLUT();
   int bitsample = lut.GetBitSample();
   assert( bitsample );
+  (void)bitsample;//warning removal
 
   //const DataElement& pixeldata = image.GetDataElement();
   //const ByteValue *bv = pixeldata.GetByteValue();
@@ -49,7 +49,8 @@ bool ImageApplyLookupTable::Apply()
 
   DataElement &de = Output->GetDataElement();
   std::string str = os.str();
-  de.SetByteValue( str.c_str(), str.size() );
+  VL::Type strSize = (VL::Type)str.size();
+  de.SetByteValue( str.c_str(), strSize);
   Output->GetLUT().Clear();
   Output->SetPhotometricInterpretation( PhotometricInterpretation::RGB );
   Output->GetPixelFormat().SetSamplesPerPixel( 3 );
@@ -73,4 +74,3 @@ bool ImageApplyLookupTable::Apply()
 
 
 } // end namespace gdcm
-
