@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -146,6 +145,15 @@ bool ImageChangeTransferSyntax::TryJPEGCodec(const DataElement &pixelde, Bitmap
   const TransferSyntax &ts = GetTransferSyntax();
 
   JPEGCodec jpgcodec;
+  // pass lossy/lossless flag:
+  // JPEGCodec are easier to deal with since there is no dual transfer syntax
+  // that can be both lossy and lossless:
+  if( ts.IsLossy() )
+    {
+    assert( !ts.IsLossless() );
+    jpgcodec.SetLossless( false );
+    }
+
   ImageCodec *codec = &jpgcodec;
   if( UserCodec && UserCodec->CanCode( ts ) )
     {
@@ -351,15 +359,15 @@ bool ImageChangeTransferSyntax::Change()
     {
     // In memory decompression:
     gdcm::DataElement pixeldata( gdcm::Tag(0x7fe0,0x0010) );
-    gdcm::ByteValue *bv = new gdcm::ByteValue();
-    unsigned long len = Input->GetBufferLength();
-    bv->SetLength( len );
-    bool b = Input->GetBuffer( (char*)bv->GetPointer() );
+    gdcm::ByteValue *bv0 = new gdcm::ByteValue();
+    unsigned long len0 = Input->GetBufferLength();
+    bv0->SetLength( len0 );
+    bool b = Input->GetBuffer( (char*)bv0->GetPointer() );
     if( !b )
       {
       return false;
       }
-    pixeldata.SetValue( *bv );
+    pixeldata.SetValue( *bv0 );
 
     bool success = false;
     if( !success ) success = TryRAWCodec(pixeldata, *Input, *Output);
@@ -377,32 +385,32 @@ bool ImageChangeTransferSyntax::Change()
     // same goes for icon
     gdcm::DataElement iconpixeldata( gdcm::Tag(0x7fe0,0x0010) );
     if( !Input->GetIconImage().IsEmpty() )
-{
-    // same goes for icon
-    gdcm::ByteValue *bv = new gdcm::ByteValue();
-    unsigned long len = Input->GetIconImage().GetBufferLength();
-    bv->SetLength( len );
-    bool bb = Input->GetIconImage().GetBuffer( (char*)bv->GetPointer() );
-    if( !bb )
       {
-      return false;
-      }
-    iconpixeldata.SetValue( *bv );
+      // same goes for icon
+      gdcm::ByteValue *bv = new gdcm::ByteValue();
+      unsigned long len = Input->GetIconImage().GetBufferLength();
+      bv->SetLength( len );
+      bool bb = Input->GetIconImage().GetBuffer( (char*)bv->GetPointer() );
+      if( !bb )
+        {
+        return false;
+        }
+      iconpixeldata.SetValue( *bv );
 
-    success = false;
-    if( !success ) success = TryRAWCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
-    if( !success ) success = TryJPEGCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
-    if( !success ) success = TryJPEGLSCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
-    if( !success ) success = TryJPEG2000Codec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
-    if( !success ) success = TryRLECodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
-    Output->GetIconImage().SetTransferSyntax( TS );
-    if( !success )
-      {
-      //assert(0);
-      return false;
+      success = false;
+      if( !success ) success = TryRAWCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
+      if( !success ) success = TryJPEGCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
+      if( !success ) success = TryJPEGLSCodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
+      if( !success ) success = TryJPEG2000Codec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
+      if( !success ) success = TryRLECodec(iconpixeldata, Input->GetIconImage(), Output->GetIconImage());
+      Output->GetIconImage().SetTransferSyntax( TS );
+      if( !success )
+        {
+        //assert(0);
+        return false;
+        }
+      assert( Output->GetIconImage().GetTransferSyntax() == TS );
       }
-    assert( Output->GetIconImage().GetTransferSyntax() == TS );
-}
 
     //Output->ComputeLossyFlag();
     assert( Output->GetTransferSyntax() == TS );
