@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -205,9 +204,9 @@ bool ComputeZSpacingFromIPP(const DataSet &ds, double &zspacing)
   std::vector<double> distances;
   gdcm::SequenceOfItems::SizeType nitems = sqi->GetNumberOfItems();
   std::vector<double> dircos_subds2; dircos_subds2.resize(6);
-  for(gdcm::SequenceOfItems::SizeType i = 1; i <= nitems; ++i)
+  for(gdcm::SequenceOfItems::SizeType i0 = 1; i0 <= nitems; ++i0)
     {
-    const Item &item = sqi->GetItem(i);
+    const Item &item = sqi->GetItem(i0);
     const DataSet & subds = item.GetNestedDataSet();
     // (0020,9113) SQ (Sequence with undefined length #=1)     # u/l, 1 PlanePositionSequence
     const Tag tpms(0x0020,0x9113);
@@ -416,6 +415,33 @@ std::vector<double> ImageHelper::GetOriginValue(File const & f)
     gdcmWarningMacro( "Could not find Origin" );
     return ori;
     }
+  if( ms == MediaStorage::NuclearMedicineImageStorage )
+    {
+    const Tag t1(0x0054,0x0022);
+    if( ds.FindDataElement( t1 ) )
+      {
+      SmartPointer<SequenceOfItems> sqi = ds.GetDataElement( t1 ).GetValueAsSQ();
+      if( sqi )
+        {
+        // Get first item:
+        const Item &item = sqi->GetItem(1);
+        const DataSet & subds = item.GetNestedDataSet();
+        const Tag timagepositionpatient(0x0020, 0x0032);
+        assert( subds.FindDataElement( timagepositionpatient ) );
+        Attribute<0x0020,0x0032> at = {{0,0,0}}; // default value if empty
+        at.SetFromDataSet( subds );
+        ori.resize( at.GetNumberOfValues() );
+        for( unsigned int i = 0; i < at.GetNumberOfValues(); ++i )
+          {
+          ori[i] = at.GetValue(i);
+          }
+        return ori;
+        }
+      }
+    ori.resize( 3 );
+    gdcmWarningMacro( "Could not find Origin" );
+    return ori;
+    }
   ori.resize( 3 );
 
   // else
@@ -523,6 +549,37 @@ std::vector<double> ImageHelper::GetDirectionCosinesValue(File const & f)
       return dircos;
       }
     }
+  if( ms == MediaStorage::NuclearMedicineImageStorage )
+    {
+    const Tag t1(0x0054,0x0022);
+    if( ds.FindDataElement( t1 ) )
+      {
+      SmartPointer<SequenceOfItems> sqi = ds.GetDataElement( t1 ).GetValueAsSQ();
+      if( sqi )
+        {
+        // Get first item:
+        const Item &item = sqi->GetItem(1);
+        const DataSet & subds = item.GetNestedDataSet();
+
+        dircos.resize( 6 );
+        bool b2 = ImageHelper::GetDirectionCosinesFromDataSet(subds, dircos);
+        if( b2 )
+          {
+          }
+        else
+          {
+          gdcmErrorMacro( "Image Orientation (Patient) was not found" );
+          dircos[0] = 1;
+          dircos[1] = 0;
+          dircos[2] = 0;
+          dircos[3] = 0;
+          dircos[4] = 1;
+          dircos[5] = 0;
+          }
+        return dircos;
+        }
+      }
+    }
 
   dircos.resize( 6 );
   if( ms == MediaStorage::SecondaryCaptureImageStorage || !GetDirectionCosinesFromDataSet(ds, dircos) )
@@ -678,6 +735,7 @@ std::vector<unsigned int> ImageHelper::GetDimensionsValue(const File& f)
     //  theReturn[1] = 1;
     //  }
   }
+#if 0
   // D 0054|0081 [US] [Planes] [512]
   {
     //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
@@ -696,6 +754,19 @@ std::vector<unsigned int> ImageHelper::GetDimensionsValue(const File& f)
     //  theReturn[1] = 1;
     //  }
   }
+#else
+  {
+  Attribute<0x0028,0x0008> at = { 0 };
+  at.SetFromDataSet( ds );
+  int numberofframes = at.GetValue();
+  theReturn[2] = 1;
+  if( numberofframes > 1 )
+    {
+    theReturn[2] = at.GetValue();
+    }
+  }
+
+#endif
   return theReturn;
 }
 
@@ -861,6 +932,7 @@ Tag ImageHelper::GetZSpacingTagFromMediaStorage(MediaStorage const &ms)
   switch(ms)
     {
   case MediaStorage::MRImageStorage:
+  case MediaStorage::NuclearMedicineImageStorage: // gdcmData/Nm.dcm
   case MediaStorage::GeneralElectricMagneticResonanceImageStorage:
     // (0018,0088) DS [3]                                      #   2, 1 SpacingBetweenSlices
     t = Tag(0x0018,0x0088);
@@ -901,7 +973,6 @@ Warning - Dicom dataset contains attributes not present in standard DICOM IOD -
   case MediaStorage::RTDoseStorage: // gdcmData/BogugsItemAndSequenceLengthCorrected.dcm
     t = Tag(0x3004,0x000c);
     break;
-  case MediaStorage::NuclearMedicineImageStorage: // gdcmData/Nm.dcm
   case MediaStorage::GEPrivate3DModelStorage:
   case MediaStorage::Philips3D:
   case MediaStorage::VideoEndoscopicImageStorage:
@@ -1350,11 +1421,11 @@ void SetDataElementInSQAsItemNumber(DataSet & ds, DataElement const & de, Tag co
     if( !ds.FindDataElement( tfgs ) )
       {
       sqi = new SequenceOfItems;
-      DataElement de( tfgs );
-      de.SetVR( VR::SQ );
-      de.SetValue( *sqi );
-      de.SetVLToUndefined();
-      ds.Insert( de );
+      DataElement detmp( tfgs );
+      detmp.SetVR( VR::SQ );
+      detmp.SetValue( *sqi );
+      detmp.SetVLToUndefined();
+      ds.Insert( detmp );
       }
     //sqi = (SequenceOfItems*)ds.GetDataElement( tfgs ).GetSequenceOfItems();
     sqi = ds.GetDataElement( tfgs ).GetValueAsSQ();
@@ -1372,11 +1443,11 @@ void SetDataElementInSQAsItemNumber(DataSet & ds, DataElement const & de, Tag co
     if( !subds.FindDataElement( tpms ) )
       {
       SequenceOfItems *sqi2 = new SequenceOfItems;
-      DataElement de( tpms );
-      de.SetVR( VR::SQ );
-      de.SetValue( *sqi2 );
-      de.SetVLToUndefined();
-      subds.Insert( de );
+      DataElement detmp( tpms );
+      detmp.SetVR( VR::SQ );
+      detmp.SetValue( *sqi2 );
+      detmp.SetVLToUndefined();
+      subds.Insert( detmp );
       }
 
     //sqi = (SequenceOfItems*)subds.GetDataElement( tpms ).GetSequenceOfItems();
