@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -18,15 +17,7 @@
 #include "gdcmDataElement.h"
 
 // CharLS includes
-#include "gdcmcharls/stdafx.h" // sigh...
-#include "gdcmcharls/interface.h"
-#include "gdcmcharls/util.h"
-#include "gdcmcharls/defaulttraits.h"
-#include "gdcmcharls/losslesstraits.h"
-#include "gdcmcharls/colortransform.h"
-#include "gdcmcharls/streams.h"
-#include "gdcmcharls/processline.h"
-
+#include "gdcm_charls.h"
 
 namespace gdcm
 {
@@ -56,12 +47,18 @@ bool JPEGLSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
 #else
   is.seekg( 0, std::ios::end);
   std::streampos buf_size = is.tellg();
-  char *dummy_buffer = new char[buf_size];
+  //assert(buf_size < INT_MAX);
+  char *dummy_buffer = new char[(unsigned int)buf_size];
   is.seekg(0, std::ios::beg);
   is.read( dummy_buffer, buf_size);
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+  JlsParameters metadata;
+#else
   JlsParamaters metadata;
-  if (JpegLsReadHeader(dummy_buffer, buf_size, &metadata) != OK)
+#endif
+  //assert(buf_size < INT_MAX);
+  if (JpegLsReadHeader(dummy_buffer, (unsigned int)buf_size, &metadata) != OK)
     {
     return false;
     }
@@ -114,7 +111,7 @@ bool JPEGLSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
   else assert(0);
 
   // allowedlossyerror == 0 => Lossless
-  LossyFlag = metadata.allowedlossyerror;
+  LossyFlag = metadata.allowedlossyerror != 0;
 
   if( metadata.allowedlossyerror == 0 )
     {
@@ -165,19 +162,27 @@ bool JPEGLSCodec::Decode(DataElement const &in, DataElement &out)
     sf->GetBuffer(buffer, totalLen);
     //is.write(buffer, totalLen);
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JlsParameters metadata;
+#else
     JlsParamaters metadata;
+#endif
     if (JpegLsReadHeader(buffer, totalLen, &metadata) != OK)
       {
       return false;
       }
 
     // allowedlossyerror == 0 => Lossless
-    LossyFlag = metadata.allowedlossyerror;
+    LossyFlag = metadata.allowedlossyerror!= 0;
 
     const BYTE* pbyteCompressed = (const BYTE*)buffer;
     int cbyteCompressed = totalLen;
 
-    JlsParamaters params = {0};
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JlsParameters params = {};
+#else
+    JlsParamaters params = {};
+#endif
     JpegLsReadHeader(pbyteCompressed, cbyteCompressed, &params);
 
     std::vector<BYTE> rgbyteCompressed;
@@ -186,11 +191,19 @@ bool JPEGLSCodec::Decode(DataElement const &in, DataElement &out)
     std::vector<BYTE> rgbyteOut;
     rgbyteOut.resize(params.height *params.width * ((params.bitspersample + 7) / 8) * params.components);
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JLS_ERROR result = JpegLsDecode(&rgbyteOut[0], rgbyteOut.size(), pbyteCompressed, cbyteCompressed, &params);
+#else
     JLS_ERROR result = JpegLsDecode(&rgbyteOut[0], rgbyteOut.size(), pbyteCompressed, cbyteCompressed);
+#endif
     ASSERT(result == OK);
 
     delete[] buffer;
 
+    if (result != OK)
+      {
+      return false;
+      }
     out = in;
 
     out.SetByteValue( (char*)&rgbyteOut[0], rgbyteOut.size() );
@@ -221,19 +234,27 @@ bool JPEGLSCodec::Decode(DataElement const &in, DataElement &out)
   // what if 0xd9 is never found ?
   assert( totalLen > 0 && pbyteCompressed[totalLen-1] == 0xd9 );
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JlsParameters metadata;
+#else
     JlsParamaters metadata;
+#endif
     if (JpegLsReadHeader(mybuffer, totalLen, &metadata) != OK)
       {
       return false;
       }
 
     // allowedlossyerror == 0 => Lossless
-    LossyFlag = metadata.allowedlossyerror;
+    LossyFlag = metadata.allowedlossyerror!= 0;
 
 
     int cbyteCompressed = totalLen;
 
-    JlsParamaters params = {0};
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JlsParameters params = {};
+#else
+    JlsParamaters params = {};
+#endif
     JpegLsReadHeader(pbyteCompressed, cbyteCompressed, &params);
 
     std::vector<BYTE> rgbyteCompressed;
@@ -242,12 +263,19 @@ bool JPEGLSCodec::Decode(DataElement const &in, DataElement &out)
     std::vector<BYTE> rgbyteOut;
     rgbyteOut.resize(params.height *params.width * ((params.bitspersample + 7) / 8) * params.components);
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JLS_ERROR result = JpegLsDecode(&rgbyteOut[0], rgbyteOut.size(), pbyteCompressed, cbyteCompressed, &params);
+#else
     JLS_ERROR result = JpegLsDecode(&rgbyteOut[0], rgbyteOut.size(), pbyteCompressed, cbyteCompressed);
+#endif
     ASSERT(result == OK);
-bool r = true;
+    bool r = true;
 
 
       delete[] mybuffer;
+      if (result != OK){
+        return false;
+      }
     os.write( (char*)&rgbyteOut[0], rgbyteOut.size() );
 
       if(!r) return false;
@@ -298,7 +326,11 @@ bool JPEGLSCodec::Code(DataElement const &in, DataElement &out)
     {
     const char *inputdata = input + dim * image_len; //bv->GetPointer();
 
+#ifdef GDCM_USE_SYSTEM_CHARLS
+    JlsParameters params = {};
+#else
     JlsParamaters params = {};
+#endif
 /*
 The fields in JlsCustomParameters do not control lossy/lossless. They
 provide the possiblity to tune the JPEG-LS internals for better compression
@@ -386,4 +418,11 @@ void JPEGLSCodec::SetLossyError(int error)
   LossyError = error;
 }
 
+bool JPEGLSCodec::Decode(DataElement const &, char* , uint32_t ,
+              uint32_t , uint32_t , uint32_t ,
+              uint32_t , uint32_t , uint32_t )
+{
+ return false;
+}
+
 } // end namespace gdcm
