@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -140,6 +139,7 @@ unsigned int Overlay::GetNumberOfOverlays(DataSet const & ds)
       Tag toverlaydata(overlay.GetGroup(),0x3000 );
       Tag toverlayrows(overlay.GetGroup(),0x0010 );
       Tag toverlaycols(overlay.GetGroup(),0x0011 );
+      Tag toverlaybitpos(overlay.GetGroup(),0x0102 );
       if( ds.FindDataElement( toverlaydata ) )
         {
         // ok so far so good...
@@ -150,15 +150,16 @@ unsigned int Overlay::GetNumberOfOverlays(DataSet const & ds)
           ++numoverlays;
           }
         }
-      else if( ds.FindDataElement( toverlayrows ) && ds.FindDataElement( toverlaycols ) )
+      else if( ds.FindDataElement( toverlayrows ) && ds.FindDataElement( toverlaycols )
+        && ds.FindDataElement( toverlaybitpos ) )
         {
         // Overlay Pixel are in Unused Pixel
         assert( !ds.FindDataElement( toverlaydata ) );
         const DataElement& overlayrows = ds.GetDataElement( toverlayrows );
         const DataElement& overlaycols = ds.GetDataElement( toverlaycols );
-        Tag toverlaybitpos(overlay.GetGroup(),0x0102 );
         assert( ds.FindDataElement( toverlaybitpos ) );
-        if( !overlayrows.IsEmpty() && !overlaycols.IsEmpty() )
+        const DataElement& overlaybitpos = ds.GetDataElement( toverlaybitpos );
+        if( !overlayrows.IsEmpty() && !overlaycols.IsEmpty() && !overlaybitpos.IsEmpty() )
           {
           ++numoverlays;
           }
@@ -343,6 +344,10 @@ bool Overlay::GrabOverlayFromPixelData(DataSet const &ds)
     const uint16_t *end = (uint16_t*)(array + length);
     //const unsigned int ovlength = length / (8*2);
     assert( 8 * ovlength == (unsigned int)Internal->Rows * Internal->Columns );
+    if( Internal->Data.empty() )
+      {
+      return false;
+      }
     unsigned char * overlay = (unsigned char*)&Internal->Data[0];
     int c = 0;
     uint16_t pmask = 1 << Internal->BitPosition;
