@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -30,12 +29,12 @@ PNMCodec::~PNMCodec()
 {
 }
 
-bool PNMCodec::CanDecode(TransferSyntax const &ts) const
+bool PNMCodec::CanDecode(TransferSyntax const &) const
 {
   return false;
 }
 
-bool PNMCodec::CanCode(TransferSyntax const &ts) const
+bool PNMCodec::CanCode(TransferSyntax const &) const
 {
   return false;
 }
@@ -47,7 +46,7 @@ bool PNMCodec::Write(const char *filename, const DataElement &out) const
   std::ofstream os(filename);
   const unsigned int *dims = this->GetDimensions();
   const PhotometricInterpretation &pi = this->GetPhotometricInterpretation();
-  if( pi == PhotometricInterpretation::MONOCHROME2 
+  if( pi == PhotometricInterpretation::MONOCHROME2
     || pi == PhotometricInterpretation::MONOCHROME1 ) // warning viz will be surprising
     {
     os << "P5\n";
@@ -62,7 +61,7 @@ bool PNMCodec::Write(const char *filename, const DataElement &out) const
     return false;
     }
   os << dims[0] << " " << dims[1] << "\n";
-  
+
   const PixelFormat& pf = GetPixelFormat();
   switch(pf)
     {
@@ -82,7 +81,7 @@ bool PNMCodec::Write(const char *filename, const DataElement &out) const
 
   const gdcm::ByteValue *bv = out.GetByteValue();
   // FIXME: PNM Codec cannot handle encapsulated syntax... sigh
-  if(!bv) 
+  if(!bv)
     {
     gdcmErrorMacro( "PNM Codec does not handle compress syntax. You need to decompress first." );
     return false;
@@ -116,7 +115,7 @@ bool PNMCodec::Read(const char *filename, DataElement &out) const
     pi = gdcm::PhotometricInterpretation::MONOCHROME2;
   else if( type == "P6" )
     pi = gdcm::PhotometricInterpretation::RGB;
-  else 
+  else
     {
     std::cerr << "Unhandled PGM type: " << type << std::endl;
     return false;
@@ -138,7 +137,8 @@ bool PNMCodec::Read(const char *filename, DataElement &out) const
     is.get();
     }
   std::streampos pos = is.tellg();
-  size_t m = (len - pos ) / ( dims[0]*dims[1] );
+  //assert(pos < INT_MAX);
+  size_t m = (len - (size_t)pos ) / ( dims[0]*dims[1] );
   if( m * dims[0] * dims[1] != len - pos )
     {
     std::cerr << "Problem computing length" << std::endl;
@@ -180,7 +180,8 @@ bool PNMCodec::Read(const char *filename, DataElement &out) const
   if( !is.eof() ) return false;
 
   out.SetTag( gdcm::Tag(0x7fe0,0x0010) );
-  out.SetByteValue( buf, pdlen );
+  VL::Type pdLenSize = (VL::Type)pdlen;
+  out.SetByteValue( buf, pdLenSize );
   delete[] buf;
 
   is.close();
@@ -191,7 +192,8 @@ bool PNMCodec::Read(const char *filename, DataElement &out) const
 bool PNMCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
 {
   is.seekg( 0, std::ios::end );
-  size_t len = is.tellg();
+  std::streampos len = is.tellg();
+  //assert(len < INT_MAX);
   is.seekg( 0, std::ios::beg );
 
   std::string type, str;
@@ -201,7 +203,7 @@ bool PNMCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
     pi = gdcm::PhotometricInterpretation::MONOCHROME2;
   else if( type == "P6" ) // P3 => ASCII
     pi = gdcm::PhotometricInterpretation::RGB;
-  else 
+  else
     {
     std::cerr << "Unhandled PGM type: " << type << std::endl;
     return false;
@@ -222,8 +224,10 @@ bool PNMCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
     {
     is.get();
     }
-  std::streampos pos = is.tellg();
-  size_t m = (len - pos ) / ( dims[0]*dims[1] );
+  std::streamoff pos = is.tellg();
+  //assert(len < INT_MAX);
+  //assert(pos < INT_MAX);
+  size_t m = ((size_t)len - (size_t)pos ) / ( dims[0]*dims[1] );
   if( m * dims[0] * dims[1] != len - pos )
     {
     std::cerr << "Problem computing length" << std::endl;
