@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -181,14 +180,6 @@ bool PixmapReader::Read()
 void DoIconImage(const DataSet& rootds, Pixmap& image)
 {
   const Tag ticonimage(0x0088,0x0200);
-  const PrivateTag tgeiconimage(0x0009,0x0010,"GEIIS");
-  // AFAIK this icon SQ is undocumented , but I found it in:
-  // gdcmDataExtra/gdcmBreakers/2929J888_8b_YBR_RLE_PlanConf0_breaker.dcm
-  // aka 'SmallPreview'
-  // The SQ contains a DataElement:
-  // (0002,0010) UI [1.2.840.10008.1.2.1]                          # 20,1 Transfer Syntax UID
-  // sigh...
-  const PrivateTag tgeiconimage2(0x6003,0x0010,"GEMS_Ultrasound_ImageGroup_001");
   IconImage &pixeldata = image.GetIconImage();
   if( rootds.FindDataElement( ticonimage ) )
     {
@@ -320,7 +311,8 @@ void DoIconImage(const DataSet& rootds, Pixmap& image)
           unsigned long check =
             (el_us3.GetValue(0) ? el_us3.GetValue(0) : 65536)
             * el_us3.GetValue(2) / 8;
-          assert( check == lut_raw->GetLength() ); (void)check;
+          assert( check == lut_raw->GetLength()
+            || check + 1 == lut_raw->GetLength() ); (void)check;
           }
         else if( ds.FindDataElement( seglut ) )
           {
@@ -356,203 +348,13 @@ void DoIconImage(const DataSet& rootds, Pixmap& image)
     pixeldata.SetDataElement( de );
 
     // Pass TransferSyntax:
-    pixeldata.SetTransferSyntax( image.GetTransferSyntax() );
-    }
-  else if( false && rootds.FindDataElement( tgeiconimage ) )
-    {
-    const DataElement &iconimagesq = rootds.GetDataElement( tgeiconimage );
-    //const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
-    SmartPointer<SequenceOfItems> sq = iconimagesq.GetValueAsSQ();
-    // Is SQ empty ?
-    if( !sq ) return;
-    SequenceOfItems::ConstIterator it = sq->Begin();
-    const DataSet &ds = it->GetNestedDataSet();
-
-    // D 0028|0011 [US] [Columns] [512]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0011) );
-      Attribute<0x0028,0x0011> at = { 0 };
-      at.SetFromDataSet( ds );
-      pixeldata.SetDimension(0, at.GetValue() );
-      }
-
-    // D 0028|0010 [US] [Rows] [512]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
-      Attribute<0x0028,0x0010> at = { 0 };
-      at.SetFromDataSet( ds );
-      pixeldata.SetDimension(1, at.GetValue() );
-      }
-
-    PixelFormat pf;
-    // D 0028|0100 [US] [Bits Allocated] [16]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0100) );
-      Attribute<0x0028,0x0100> at = { 0 };
-      at.SetFromDataSet( ds );
-      pf.SetBitsAllocated( at.GetValue() );
-      }
-    // D 0028|0101 [US] [Bits Stored] [12]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0101) );
-      Attribute<0x0028,0x0101> at = { 0 };
-      at.SetFromDataSet( ds );
-      pf.SetBitsStored( at.GetValue() );
-      }
-    // D 0028|0102 [US] [High Bit] [11]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0102) );
-      Attribute<0x0028,0x0102> at = { 0 };
-      at.SetFromDataSet( ds );
-      pf.SetHighBit( at.GetValue() );
-      }
-    // D 0028|0103 [US] [Pixel Representation] [0]
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0103) );
-      Attribute<0x0028,0x0103> at = { 0 };
-      at.SetFromDataSet( ds );
-      pf.SetPixelRepresentation( at.GetValue() );
-      }
-    // (0028,0002) US 1                                        #   2, 1 SamplesPerPixel
-      {
-      //const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0002) );
-      Attribute<0x0028,0x0002> at = { 1 };
-      at.SetFromDataSet( ds );
-      pf.SetSamplesPerPixel( at.GetValue() );
-      }
-    pixeldata.SetPixelFormat( pf );
-    // D 0028|0004 [CS] [Photometric Interpretation] [MONOCHROME2 ]
-    const Tag tphotometricinterpretation(0x0028, 0x0004);
-    assert( ds.FindDataElement( tphotometricinterpretation ) );
-    const ByteValue *photometricinterpretation = ds.GetDataElement( tphotometricinterpretation ).GetByteValue();
-    std::string photometricinterpretation_str(
-      photometricinterpretation->GetPointer(),
-      photometricinterpretation->GetLength() );
-    PhotometricInterpretation pi(
-      PhotometricInterpretation::GetPIType(
-        photometricinterpretation_str.c_str()));
-    assert( pi != PhotometricInterpretation::UNKNOW);
-    pixeldata.SetPhotometricInterpretation( pi );
-    const Tag tpixeldata = Tag(0x7fe0, 0x0010);
-    assert( ds.FindDataElement( tpixeldata ) );
-      {
-      const DataElement& de = ds.GetDataElement( tpixeldata );
-      JPEGCodec jpeg;
-      jpeg.SetPhotometricInterpretation( pixeldata.GetPhotometricInterpretation() );
-      jpeg.SetPlanarConfiguration( 0 );
-      PixelFormat pf = pixeldata.GetPixelFormat();
-      // Apparently bits stored can only be 8 or 12:
-      if( pf.GetBitsStored() == 16 )
-        {
-        pf.SetBitsStored( 12 );
-        }
-      jpeg.SetPixelFormat( pf );
-      DataElement de2;
-      jpeg.Decode( de, de2);
-      pixeldata.SetDataElement( de2 );
-      }
-    }
-  else if( false && rootds.FindDataElement( tgeiconimage2 ) )
-    {
-    const DataElement &iconimagesq = rootds.GetDataElement( tgeiconimage2 );
-    //const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
-    SmartPointer<SequenceOfItems> sq = iconimagesq.GetValueAsSQ();
-    // Is SQ empty ?
-    if( !sq ) return;
-    SequenceOfItems::ConstIterator it = sq->Begin();
-    const DataSet &ds = it->GetNestedDataSet();
-
-    // D 0028|0011 [US] [Columns] [512]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0011) );
-      Attribute<0x0028,0x0011> at;
-      at.SetFromDataElement( de );
-      pixeldata.SetDimension(0, at.GetValue() );
-      }
-
-    // D 0028|0010 [US] [Rows] [512]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0010) );
-      Attribute<0x0028,0x0010> at;
-      at.SetFromDataElement( de );
-      pixeldata.SetDimension(1, at.GetValue() );
-      }
-
-    PixelFormat pf;
-    // D 0028|0100 [US] [Bits Allocated] [16]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0100) );
-      Attribute<0x0028,0x0100> at;
-      at.SetFromDataElement( de );
-      pf.SetBitsAllocated( at.GetValue() );
-      }
-    // D 0028|0101 [US] [Bits Stored] [12]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0101) );
-      Attribute<0x0028,0x0101> at;
-      at.SetFromDataElement( de );
-      pf.SetBitsStored( at.GetValue() );
-      }
-    // D 0028|0102 [US] [High Bit] [11]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0102) );
-      Attribute<0x0028,0x0102> at;
-      at.SetFromDataElement( de );
-      pf.SetHighBit( at.GetValue() );
-      }
-    // D 0028|0103 [US] [Pixel Representation] [0]
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0103) );
-      Attribute<0x0028,0x0103> at;
-      at.SetFromDataElement( de );
-      pf.SetPixelRepresentation( at.GetValue() );
-      }
-    // (0028,0002) US 1                                        #   2, 1 SamplesPerPixel
-      {
-      const DataElement& de = ds.GetDataElement( Tag(0x0028, 0x0002) );
-      Attribute<0x0028,0x0002> at;
-      at.SetFromDataElement( de );
-      pf.SetSamplesPerPixel( at.GetValue() );
-      }
-    pixeldata.SetPixelFormat( pf );
-    // D 0028|0004 [CS] [Photometric Interpretation] [MONOCHROME2 ]
-    const Tag tphotometricinterpretation(0x0028, 0x0004);
-    assert( ds.FindDataElement( tphotometricinterpretation ) );
-    const ByteValue *photometricinterpretation = ds.GetDataElement( tphotometricinterpretation ).GetByteValue();
-    std::string photometricinterpretation_str(
-      photometricinterpretation->GetPointer(),
-      photometricinterpretation->GetLength() );
-    PhotometricInterpretation pi(
-      PhotometricInterpretation::GetPIType(
-        photometricinterpretation_str.c_str()));
-    assert( pi != PhotometricInterpretation::UNKNOW);
-    pixeldata.SetPhotometricInterpretation( pi );
-    //const Tag tpixeldata = Tag(0x7fe0, 0x0010);
-    const PrivateTag tpixeldata(0x6003,0x0011,"GEMS_Ultrasound_ImageGroup_001");
-    assert( ds.FindDataElement( tpixeldata ) );
-      {
-      const DataElement& de = ds.GetDataElement( tpixeldata );
-      pixeldata.SetDataElement( de );
-      /*
-      JPEGCodec jpeg;
-      jpeg.SetPhotometricInterpretation( pixeldata.GetPhotometricInterpretation() );
-      jpeg.SetPlanarConfiguration( 0 );
-      PixelFormat pf = pixeldata.GetPixelFormat();
-      // Apparently bits stored can only be 8 or 12:
-      if( pf.GetBitsStored() == 16 )
-      {
-      pf.SetBitsStored( 12 );
-      }
-      jpeg.SetPixelFormat( pf );
-      DataElement de2;
-      jpeg.Decode( de, de2);
-      pixeldata.SetDataElement( de2 );
-       */
-      }
-    }
-  else
-    {
-    //gdcmDebugMacro( "No icon found" );
+    // Warning This is legal for the Icon to be uncompress in a compressed image
+    // We need to set the appropriate TS here:
+    const ByteValue *bv = de.GetByteValue();
+    if( bv )
+      pixeldata.SetTransferSyntax( TransferSyntax::ImplicitVRLittleEndian );
+    else
+      pixeldata.SetTransferSyntax( image.GetTransferSyntax() );
     }
 }
 
@@ -609,7 +411,7 @@ void DoCurves(const DataSet& ds, Pixmap& pixeldata)
     }
 }
 
-void DoOverlays(const DataSet& ds, Pixmap& pixeldata)
+bool DoOverlays(const DataSet& ds, Pixmap& pixeldata)
 {
   bool updateoverlayinfo = false;
   unsigned int numoverlays;
@@ -720,12 +522,20 @@ void DoOverlays(const DataSet& ds, Pixmap& pixeldata)
       {
       Overlay& o = pixeldata.GetOverlay(ov);
       // We need to update information
-      assert( o.GetBitsAllocated() == 16 );
-      o.SetBitsAllocated( 1 );
-      o.SetBitPosition( 0 );
+      if( o.GetBitsAllocated() == 16 )
+        {
+        o.SetBitsAllocated( 1 );
+        o.SetBitPosition( 0 );
+        }
+      else
+        {
+        gdcmErrorMacro( "Overlay is not supported" );
+        return false;
+        }
       }
     }
 
+  return true;
 }
 
 bool PixmapReader::ReadImage(MediaStorage const &ms)
@@ -1141,7 +951,10 @@ bool PixmapReader::ReadImage(MediaStorage const &ms)
   DoCurves(ds, *PixelData);
 
   // 7. Do the Overlays if any
-  DoOverlays(ds, *PixelData);
+  if( !DoOverlays(ds, *PixelData) )
+    {
+    return false;
+    }
 
   // 8. Do the PixelData
   if( ms == MediaStorage::MRSpectroscopyStorage )
@@ -1425,6 +1238,7 @@ bool PixmapReader::ReadACRNEMAImage()
     PhotometricInterpretation pi(
       PhotometricInterpretation::GetPIType(
         photometricinterpretation_str.c_str()));
+    PixelData->SetPhotometricInterpretation( pi );
     }
   else
     {
