@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -969,7 +968,7 @@ VR Printer::PrintDataElement(std::ostringstream &os, const Dicts &dicts, const D
       // What ? A public element that we do not know about !!!
       os << GDCM_TERMINAL_VT100_BLINK;
       }
-    os << " UNKNOWN";
+    os << " GDCM:UNKNOWN"; // Special keyword
     os << GDCM_TERMINAL_VT100_NORMAL;
     }
   os << "\n";
