@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -87,7 +86,7 @@ double frap(double frac[2], double startx, double maxden = 10 )
   const double error = startx - ((double) m[0][0] / (double) m[1][0]);
 
   /* now try other possibility */
-  ai = (maxden - m[1][1]) / m[1][0];
+  ai = ((long)maxden - m[1][1]) / m[1][0];
   m[0][0] = m[0][0] * ai + m[0][1];
   m[1][0] = m[1][0] * ai + m[1][1];
   //printf("%ld/%ld, error = %e\n", m[0][0], m[1][0],
