@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -19,6 +18,7 @@
 #include "gdcmTesting.h"
 
 #include <iostream>
+#include <cstring> // strcmp
 
 static const char * const gdcmMD5SumFiles[][2] = {
 { "f5ae1418f6ec07ae13522c18ff1e067a"  , "00191113.dcm" },
@@ -215,7 +215,11 @@ static const char * const gdcmMD5SumFiles[][2] = {
 { "346ba438ade47d75c41e637858a419f8"  , "OsirixFake16BitsStoredFakeSpacing.dcm" },
 { "efe1ff2da3fc0bfcc5df834fa390d5cf"  , "MR16BitsAllocated_8BitsStored.dcm" },
 { "7900d059078278ad0387f7c4aaf2027d"  , "JPEGDefinedLengthSequenceOfFragments.dcm" },
-
+{ "dacb240b2fc701416d80193ad18baad5"  , "IM-0001-0066.CommandTag00.dcm" },
+{ "7f2f84d3adef913bb5531f583eceb004"  , "UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" },
+{ "f4bf27280aad0ff38d1fe3871a0a8afb"  , "GDCMJ2K_TextGBR.dcm" },
+{ "f445a6dc674e2c12c14bf3583c6c3e6f"  , "NM_Kakadu44_SOTmarkerincons.dcm" },
+{ "7c0c4eb0c73b4dc5b3a4d961653fc4e2"  , "PhilipsInteraSeqTermInvLen.dcm" },
 { NULL, NULL}
 };
 
@@ -242,8 +246,8 @@ int TestMD5Func(const char* filename, const char *md5ref, bool verbose = false)
     std::cout << "Problem with: " << path << std::endl;
     std::cout << "Ref: " << md5ref << " vs " << md5 << std::endl;
     // Let's remove this buggy file:
-    std::cout << "Removing: " << path << std::endl;
-    gdcm::System::RemoveFile(path.c_str());
+    //std::cout << "Removing: " << path << std::endl;
+    //gdcm::System::RemoveFile(path.c_str());
     return 1;
     }
   return 0;
@@ -270,11 +274,11 @@ static const char *GetMD5Sum(const char *filename)
 
 int TestMD5(int argc, char *argv[])
 {
-//  if( argc == 2 )
-//    {
-//    const char *filename = argv[1];
-//    return TestMD5Func(filename, true);
-//    }
+  if( argc == 2 )
+    {
+    const char *filename = argv[1];
+    return TestMD5Func(filename, "", true);
+    }
 
   // else
   gdcm::Trace::DebugOff();
