@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http:/gdcm.sourceforge.net/Copyright.html for details.
 
@@ -58,7 +57,7 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "D_CLUNIE_CT1_RLE.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "undefined_length_un_vr.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "D_CLUNIE_MR4_JPLL.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "PET-cardio-Multiframe-Papyrus.dcm (could be read)},
+{ "PET-cardio-Multiframe-Papyrus.dcm", "" },
 { "dicomdir_Pms_WithVisit_WithPrivate_WithStudyComponents" , "1.2.840.10008.1.3.10"},
 { "CT_16b_signed-UsedBits13.dcm","1.2.840.10008.5.1.4.1.1.2"},
 //{ "TestAllEntryVerifyReference.txt (could not be read)},
@@ -67,7 +66,7 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "D_CLUNIE_CT2_JPLL.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "DermaColorLossLess.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "DICOMDIR" , "1.2.840.10008.1.3.10" },
-//{ "LIBIDO-24-ACR_NEMA-Rectangle.dcm (could be read)},
+{ "LIBIDO-24-ACR_NEMA-Rectangle.dcm", "" },
 { "GE_GENESIS-16-MONO2-Uncompressed-UnusualVR.dcm","1.2.840.10008.5.1.4.1.1.4"},
 //{ "MR-SIEMENS-DICOM-WithOverlays.README.txt (could not be read)},
 { "D_CLUNIE_NM1_JPLY.dcm","1.2.840.10008.5.1.4.1.1.7"},
@@ -84,12 +83,12 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "ELSCINT1_PMSCT_RLE1.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "DMCPACS_ExplicitImplicit_BogusIOP.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "MR_ELSCINT1_00e1_1042_SQ_feff_00e0_Item.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "LIBIDO-16-ACR_NEMA-Volume.dcm (could be read)},
+{ "LIBIDO-16-ACR_NEMA-Volume.dcm", "" },
 //{ "Changelog (could not be read)},
 //{ "ELSCINT1_LOSSLESS_RICE.txt (could not be read)},
 { "MR-SIEMENS-DICOM-WithOverlays.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "SIEMENS_MOSAIC_12BitsStored-16BitsJPEG.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "JDDICOM_Sample2-dcmdjpeg.dcm (could be read)},
+{ "JDDICOM_Sample2-dcmdjpeg.dcm", "" },
 { "SIEMENS_MAGNETOM-12-MONO2-FileSeq2.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "D_CLUNIE_MR3_JPLY.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "MR_Philips_Intera_PrivateSequenceExplicitVR_in_SQ_2001_e05f_item_wrong_lgt_use_NOSHADOWSEQ.dcm","1.2.840.10008.5.1.4.1.1.4"},
@@ -106,42 +105,36 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 //{ "imagesWithOverlays.README.txt (could not be read)},
 { "CT-MONO2-16-chest.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_MR4_RLE.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "gdcm-CR-DCMTK-16-NonSamplePerPix.dcm (could be read)},
+{ "gdcm-CR-DCMTK-16-NonSamplePerPix.dcm" , "" },
 { "SIEMENS_MAGNETOM-12-MONO2-FileSeq1.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "ELSCINT1_JP2vsJ2K.dcm","1.2.840.10008.5.1.4.1.1.2"},
-//{ "SIEMENS_SOMATOM-12-ACR_NEMA-ZeroLengthUs.acr.README.txt (could not be read)},
 { "D_CLUNIE_CT2_RLE.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_MR2_RLE.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "MR_Philips_Intera_No_PrivateSequenceImplicitVR.README.txt (could not be read)},
 { "OT-MONO2-8-a7.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "MR-MONO2-16-head.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "PICKER-16-MONO2-No_DicomV3_Preamble.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "gdcm-JPEG-Extended.dcm","1.2.840.10008.5.1.4.1.1.2"},
-//{ "MR-MONO2-12-angio-an1.acr (could be read)},
-//{ "README (could not be read)},
+{ "MR-MONO2-12-angio-an1.acr", ""},
 { "BugGDCM2_UndefItemWrongVL.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "D_CLUNIE_MR1_RLE.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "ELSCINT1_LOSSLESS_RICE.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "dicomdir_Pms_With_heavy_embedded_sequence" , "1.2.840.10008.1.3.10" },
 { "PICKER-16-MONO2-Nested_icon.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_VL4_RLE.dcm","1.2.840.10008.5.1.4.1.1.7"},
-//{ "GE_CT_With_Private_compressed-icon.README.txt (could not be read)},
 { "D_CLUNIE_RG1_RLE.dcm","1.2.840.10008.5.1.4.1.1.1"},
-//{ "JDDICOM_Sample2.dcm (could be read)},
+{ "JDDICOM_Sample2.dcm", "" },
 { "SIEMENS_MAGNETOM-12-MONO2-FileSeq3.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "MR_Philips_Intera_SwitchIndianess_noLgtSQItem_in_trueLgtSeq.README.txt (could not be read)},
 { "CT-MONO2-8-abdo.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "D_CLUNIE_SC1_RLE.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "LEADTOOLS_FLOWERS-24-RGB-JpegLossless.dcm","1.2.840.10008.5.1.4.1.1.7"},
-//{ "LIBIDO-8-ACR_NEMA-Lena_128_128.acr (could be read)},
+{ "LIBIDO-8-ACR_NEMA-Lena_128_128.acr" , "" },
 { "D_CLUNIE_RG3_JPLL.dcm","1.2.840.10008.5.1.4.1.1.1"},
 { "SIEMENS_CSA2.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "SIEMENS_GBS_III-16-ACR_NEMA_1-ULis2Bytes.dcm (could be read)},
+{ "SIEMENS_GBS_III-16-ACR_NEMA_1-ULis2Bytes.dcm", "" },
 { "LJPEG_BuginGDCM12.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "CT-SIEMENS-MissingPixelDataInIconSQ.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "05115014-mr-siemens-avanto-syngo-with-palette-icone.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "libido1.0-vol.acr (could be read)},
-//{ "MR_Philips_Intera_PrivateSequenceExplicitVR_in_SQ_2001_e05f_item_wrong_lgt_use_NOSHADOWSEQ.README.txt (could not be read)},
+{ "libido1.0-vol.acr" , "" },
 { "MR_Spectroscopy_SIEMENS_OF.dcm","1.2.840.10008.5.1.4.1.1.4.2"},
 { "GE_CT_With_Private_compressed-icon.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_XA1_JPLY.dcm","1.2.840.10008.5.1.4.1.1.7"},
@@ -170,17 +163,14 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "D_CLUNIE_MR4_JPLY.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "D_CLUNIE_RG3_RLE.dcm","1.2.840.10008.5.1.4.1.1.1"},
 { "SIEMENS-12-Jpeg_Process_2_4-Lossy-a.dcm","1.2.840.10008.5.1.4.1.1.2"},
-//{ "ImageRecap.txt (could not be read)},
 { "DICOMDIR-Philips-EasyVision-4200-Entries", "1.2.840.10008.1.3.10"},
 { "CT-MONO2-16-brain.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_RG2_JPLY.dcm","1.2.840.10008.5.1.4.1.1.1"},
 { "MAROTECH_CT_JP2Lossy.dcm","1.2.840.10008.5.1.4.1.1.2"},
 { "D_CLUNIE_MR1_JPLL.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "ITK_GDCM124_MultiframeSecondaryCaptureInvalid.dcm","1.2.840.10008.5.1.4.1.1.7"},
-//{ "MR_Philips-Intera_BreaksNOSHADOW.README.txt (could not be read)},
-//{ "CT-MONO2-12-lomb-an2.acr.README.txt (could not be read)},
 { "dicomdir_With_embedded_icons", "1.2.840.10008.1.3.10"},
-//{ "SIEMENS_MAGNETOM-12-ACR_NEMA_2-Modern.dcm (could be read)},
+{ "SIEMENS_MAGNETOM-12-ACR_NEMA_2-Modern.dcm", "" },
 { "MR_SIEMENS_forceLoad29-1010_29-1020.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "simpleImageWithIcon.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "D_CLUNIE_MR3_JPLL.dcm","1.2.840.10008.5.1.4.1.1.4"},
@@ -190,7 +180,7 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 //{ "TheralysGDCM120Bug.README.txt (could not be read)},
 { "GE_LOGIQBook-8-RGB-HugePreview.dcm","1.2.840.10008.5.1.4.1.1.7"},
 //{ "MR_Philips_Intera_PrivateSequenceImplicitVR.README.txt (could not be read)},
-//{ "gdcm-MR-SIEMENS-16-2.acr (could be read)},
+{ "gdcm-MR-SIEMENS-16-2.acr", ""},
 { "gdcm-MR-PHILIPS-16-Multi-Seq.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "D_CLUNIE_XA1_RLE.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "NM-MONO2-16-13x-heart.dcm","1.2.840.10008.5.1.4.1.1.20"},
@@ -209,11 +199,10 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "DX_GE_FALCON_SNOWY-VOI.dcm","1.2.840.10008.5.1.4.1.1.1.1"},
 { "US-IRAD-NoPreambleStartWith0003.dcm","1.2.840.10008.5.1.4.1.1.6"},
 { "MR-Brucker-CineTagging-NonSquarePixels.dcm","1.2.840.10008.5.1.4.1.1.4"},
-//{ "JDDICOM_Sample2-dcmdjpeg.txt (could not be read)},
 { "D_CLUNIE_VL6_RLE.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "fffc0000UN.dcm","1.2.840.10008.5.1.4.1.1.7"},
-//{ "CT-MONO2-12-lomb-an2.acr (could be read)},
+{ "CT-MONO2-12-lomb-an2.acr" , "" },
 { "SIEMENS_Sonata-12-MONO2-SQ.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "ACUSON-24-YBR_FULL-RLE-b.dcm","1.2.840.10008.5.1.4.1.1.6.1"},
 { "CT-MONO2-16-ankle.dcm","1.2.840.10008.5.1.4.1.1.7"},
@@ -225,6 +214,20 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "D_CLUNIE_VL1_RLE.dcm","1.2.840.10008.5.1.4.1.1.7"},
 { "IM-0001-0066.dcm","1.2.840.10008.5.1.4.1.1.4"},
 { "SIEMENS_MAGNETOM-12-MONO2-VRUN.dcm","1.2.840.10008.5.1.4.1.1.4"},
+{ "PhilipsInteraSeqTermInvLen.dcm","1.2.840.10008.5.1.4.1.1.4"},
+{ "PHILIPS_GDCM12xBug.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
+{ "OsirixFake16BitsStoredFakeSpacing.dcm", "1.2.840.10008.5.1.4.1.1.7" },
+{ "IM-0001-0066.CommandTag00.dcm", "1.2.840.10008.5.1.4.1.1.4" },
+{ "AMIInvalidPrivateDefinedLengthSQasUN.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
+{ "GDCMJ2K_TextGBR.dcm" , "1.2.840.10008.5.1.4.1.1.7" },
+{ "MR16BitsAllocated_8BitsStored.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
+{ "D_CLUNIE_CT1_JLSL.dcm", "1.2.840.10008.5.1.4.1.1.2" },
+{ "JPEGDefinedLengthSequenceOfFragments.dcm" , "1.2.840.10008.5.1.4.1.1.2" },
+{ "PHILIPS_GDCM12xBug2.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
+{ "DCMTK_JPEGExt_12Bits.dcm" , "1.2.840.10008.5.1.4.1.1.7" },
+{ "UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" , "1.2.840.10008.5.1.4.1.1.20" },
+{ "NM_Kakadu44_SOTmarkerincons.dcm" , "1.2.840.10008.5.1.4.1.1.1" },
+{ "D_CLUNIE_CT1_JLSN.dcm", "1.2.840.10008.5.1.4.1.1.2" },
 /* Stopping condition */
 { 0 ,0 }
 };
