@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -1238,7 +1237,7 @@ int vtkGDCMImageReader::LoadSingleFile(const char *filename, char *pointer, unsi
         {
         vtkWarningMacro( "vtkImageData Overlay have an extent that do not match the one of the image" );
         }
-      if( origin[0] != 0 || origin[1] != 0 )
+      if( origin[0] != 1 || origin[1] != 1 )
         {
         vtkWarningMacro( "Overlay with origin are not supported right now" );
         }
@@ -1433,7 +1432,7 @@ int vtkGDCMImageReader::RequestDataCompat()
     // HACK: len is moved out of the loop so that when file > 1 start failing we can still know
     // the len of the buffer...technically all files should have the same len (not checked for now)
     unsigned long len = 0;
-    for(int j = dext[4]; j <= dext[5]; ++j)
+    for(int j = dext[4]; !this->AbortExecute && j <= dext[5]; ++j)
       {
       assert( j >= 0 && j <= this->FileNames->GetNumberOfValues() );
       const char *filename = this->FileNames->GetValue( j );
