@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -661,6 +660,7 @@ int vtkGDCMImageWriter::WriteGDCMData(vtkImageData *data, int timeStep)
   // Setup LUT if any:
   if( pi == gdcm::PhotometricInterpretation::PALETTE_COLOR )
     {
+    assert( pixeltype.GetSamplesPerPixel() == 1 );
     vtkLookupTable * vtklut = data->GetPointData()->GetScalars()->GetLookupTable();
     //vtkLookupTable * vtklut = this->LookupTable;
     assert( vtklut );
@@ -864,9 +864,17 @@ int vtkGDCMImageWriter::WriteGDCMData(vtkImageData *data, int timeStep)
     SetStringValueFromTag( this->MedicalImageProperties->GetAcquisitionDate(), gdcm::Tag(0x0008,0x0022), ano);
 #if ( VTK_MAJOR_VERSION == 5 && VTK_MINOR_VERSION > 0 )
     // For ex: DICOM (0008,0030) = 162552.0705 or 230012, or 0012
-#if ( VTK_MAJOR_VERSION == 5 && VTK_MINOR_VERSION > 4 )
+#if 0
     int hour, minute, second;
     if( vtkMedicalImageProperties::GetTimeAsFields( this->MedicalImageProperties->GetStudyTime(), hour, minute, second ) )
+#else
+    time_t studytime;
+    char date[22] = { ' ' };
+    strcpy( date, "19000101" );
+    if( this->MedicalImageProperties->GetStudyTime() )
+      strncpy( date + 8 , this->MedicalImageProperties->GetStudyTime(), 22 - 8 );
+    date[21] = 0;
+    if( gdcm::System::ParseDateTime(studytime, date ) )
 #endif
       SetStringValueFromTag( this->MedicalImageProperties->GetStudyTime(), gdcm::Tag(0x0008,0x0030), ano);
 #endif
@@ -1282,4 +1290,4 @@ void vtkGDCMImageWriter::SetDirectionCosinesFromImageOrientationPatient(const do
 void vtkGDCMImageWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
-}
\ No newline at end of file
+}
